@@ -1,11 +1,20 @@
-"Main interface for ce service Client"
-import sys
-from typing import Any, Dict, List
-from botocore.client import BaseClient
-from botocore.exceptions import ClientError as Boto3ClientError
+"""
+Main interface for ce service client
 
-# pylint: disable=import-self
-import mypy_boto3_ce.client as client_scope
+Usage::
+
+    import boto3
+    from mypy_boto3.ce import CostExplorerClient
+
+    session = boto3.Session()
+
+    client: CostExplorerClient = boto3.client("ce")
+    session_client: CostExplorerClient = session.client("ce")
+"""
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
+import sys
+from typing import Any, Dict, List, TYPE_CHECKING
+from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_ce.type_defs import (
     CostCategoryRuleTypeDef,
     CreateCostCategoryDefinitionResponseTypeDef,
@@ -42,20 +51,30 @@ else:
 __all__ = ("CostExplorerClient",)
 
 
-class CostExplorerClient(BaseClient):
+class Exceptions:
+    BillExpirationException: Boto3ClientError
+    ClientError: Boto3ClientError
+    DataUnavailableException: Boto3ClientError
+    InvalidNextTokenException: Boto3ClientError
+    LimitExceededException: Boto3ClientError
+    RequestChangedException: Boto3ClientError
+    ResourceNotFoundException: Boto3ClientError
+    ServiceQuotaExceededException: Boto3ClientError
+    UnresolvableUsageUnitException: Boto3ClientError
+
+
+class CostExplorerClient:
     """
-    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client)
+    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client)
     """
 
-    exceptions: client_scope.Exceptions
+    exceptions: Exceptions
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.can_paginate)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def create_cost_category_definition(
         self,
         Name: str,
@@ -63,38 +82,34 @@ class CostExplorerClient(BaseClient):
         Rules: List[CostCategoryRuleTypeDef],
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def generate_presigned_url(
         self,
         ClientMethod: str,
         Params: Dict[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
-    ) -> None:
+    ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_cost_and_usage(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -105,10 +120,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_cost_and_usage_with_resources(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -119,10 +133,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_cost_forecast(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -140,10 +153,9 @@ class CostExplorerClient(BaseClient):
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_dimension_values(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -181,10 +193,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_reservation_coverage(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -195,10 +206,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_reservation_purchase_recommendation(
         self,
         Service: str,
@@ -219,10 +229,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_reservation_utilization(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -232,10 +241,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_rightsizing_recommendation(
         self,
         Service: str,
@@ -244,10 +252,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_savings_plans_coverage(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -259,10 +266,9 @@ class CostExplorerClient(BaseClient):
         MaxResults: int = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_savings_plans_purchase_recommendation(
         self,
         SavingsPlansType: Literal["COMPUTE_SP", "EC2_INSTANCE_SP"],
@@ -280,10 +286,9 @@ class CostExplorerClient(BaseClient):
         PageSize: int = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_savings_plans_utilization(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -291,10 +296,9 @@ class CostExplorerClient(BaseClient):
         Filter: ExpressionTypeDef = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_savings_plans_utilization_details(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -303,10 +307,9 @@ class CostExplorerClient(BaseClient):
         MaxResults: int = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_tags(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -315,10 +318,9 @@ class CostExplorerClient(BaseClient):
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_tags)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def get_usage_forecast(
         self,
         TimePeriod: DateIntervalTypeDef,
@@ -336,18 +338,16 @@ class CostExplorerClient(BaseClient):
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         """
 
-    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
     def update_cost_category_definition(
         self,
         CostCategoryArn: str,
@@ -355,17 +355,5 @@ class CostExplorerClient(BaseClient):
         Rules: List[CostCategoryRuleTypeDef],
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.38/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         """
-
-
-class Exceptions:
-    BillExpirationException: Boto3ClientError
-    ClientError: Boto3ClientError
-    DataUnavailableException: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    RequestChangedException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceQuotaExceededException: Boto3ClientError
-    UnresolvableUsageUnitException: Boto3ClientError
